summaryrefslogtreecommitdiff
path: root/recman.h
diff options
context:
space:
mode:
Diffstat (limited to 'recman.h')
-rw-r--r--recman.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/recman.h b/recman.h
index a23e958..e239b0b 100644
--- a/recman.h
+++ b/recman.h
@@ -78,10 +78,10 @@ namespace vdrlive {
cRecording const* GetByMd5Hash(std::string const & hash) const;
/**
* Rename a recording with the given hash according to
* VDRs recording mechanisms.
*/
- bool RenameRecording(cRecording const * recording, std::string const & name) const;
+ bool MoveRecording(cRecording const * recording, std::string const & name, bool copy = false) const;
/**
* Delete recording resume with the given hash according to
@@ -78,10 +78,10 @@ namespace vdrlive {
cRecording const* GetByMd5Hash(std::string const & hash) const;
/**
- * Rename a recording with the given hash according to
+ * Move a recording with the given hash according to
* VDRs recording mechanisms.
*/